==> cv-library-react-web-0.1.14.tgz: package/src/components/DataTableCell/DataTableCell.js <==
import React from 'react';
import * as PropTypes from 'prop-types';

import getStyles from './DataTableCell.styles';

const DataTableCell = (props) => {
    const {
        colDef,
        contextStyles,
        data,
        testID,
    } = props;
    const {
        field,
    } = colDef;

    const styles = getStyles(contextStyles);

    // Generate container props
    const containerProps = {
        style: styles.container,
        className: 'c-data-table-cell__container',
    };
    if (testID) { containerProps['data-test-id'] = `${testID}__data-table-cell__container`; }

    return (
        <div { ...containerProps }>
            { data[field] }
        </div>
    );
};

DataTableCell.propTypes = {
    /** Column data enhanced with ag-grid-react api */
    colDef: PropTypes.shape({
        /**
         * Cell Renderer
         * @param {Object} params column details for the cell
         */
        cellRenderer: PropTypes.func,

        /** field(unique name for col) */
        field: PropTypes.string,

        /** headerName(column header name) */
        headerName: PropTypes.string,

        /** If column is pinned */
        pinned: PropTypes.bool,

        /** Enable / disable individual resizable column (overrides global) */
        resizable: PropTypes.bool,

        /** Enable / disable individual sortable column (overrides global) */
        sortable: PropTypes.bool,

        /** Enable / disable individual movable column (overrides global) */
        suppressMovable: PropTypes.bool,

        /** Width of column */
        width: PropTypes.number,
    }),

    /** Styles for this component */
    contextStyles: PropTypes.shape({
        /** Styling for the main container */
        container: PropTypes.object,
    }),

    /** Row data */
    data: PropTypes.object,

    /** ID used for testing */
    testID: PropTypes.string,
};

export default DataTableCell;

==> cv-library-react-web-0.1.20.tgz: package/src/components/DataTableCell/DataTableCell.js <==
import React from 'react';
import * as PropTypes from 'prop-types';

import getStyles from './DataTableCell.styles';

const DataTableCell = (props) => {
    const {
        colDef,
        contextStyles,
        data,
        testID,
    } = props;

    console.log('DATA TABLE CELL: RENDER: ', props); // eslint-disable-line

    const {
        field,
    } = colDef;

    const styles = getStyles(contextStyles);

    // Generate container props
    const containerProps = {
        style: styles.container,
        className: 'c-data-table-cell__container',
    };
    if (testID) { containerProps['data-test-id'] = `${testID}__data-table-cell__container`; }

    return (
        <div { ...containerProps }>
            { data[field] }
        </div>
    );
};

DataTableCell.propTypes = {
    /** Column data enhanced with ag-grid-react api */
    colDef: PropTypes.shape({
        /**
         * Cell Renderer
         * @param {Object} params - Column details for the cell
         */
        cellRenderer: PropTypes.func,

        /** field(unique name for col) */
        field: PropTypes.string,

        /** headerName(column header name) */
        headerName: PropTypes.string,

        /** If column is pinned */
        pinned: PropTypes.bool,

        /** Enable / disable individual resizable column (overrides global) */
        resizable: PropTypes.bool,

        /** Enable / disable individual sortable column (overrides global) */
        sortable: PropTypes.bool,

        /** Enable / disable individual movable column (overrides global) */
        suppressMovable: PropTypes.bool,

        /** Width of column */
        width: PropTypes.number,
    }),

    /** Styles for this component */
    contextStyles: PropTypes.shape({
        /** Styling for the main container */
        container: PropTypes.object,
    }),

    /** Row data */
    data: PropTypes.object,

    /** ID used for testing */
    testID: PropTypes.string,
};

export default DataTableCell;
